@@ -14,6 +14,7 @@ import tempfile
 import platform
 import json
 import warnings
+from datetime import datetime, timedelta
 
 import luigi
 
@@ -69,6 +70,12 @@ class QueenbeeTask(luigi.Task):
             logging.config.fileConfig(self.log_config)
         return logger
 
+    def get_queenbee_logger(self):
+        logger = logging.getLogger('queenbee-interface')
+        if not logger.handlers:
+            logging.config.fileConfig(self.log_config)
+        return logger
+
     @property
     def input_artifacts(self):
         """Task's input artifacts.
@@ -227,8 +234,9 @@ class QueenbeeTask(luigi.Task):
         return dst_dir, dst
 
     def run(self):
+        st_time = datetime.now()
         logger = self.get_interface_logger()
-
+        qb_logger = self.get_queenbee_logger()
         # replace ' with " for Windows systems and vise versa for unix systems
         command = self.command()
         if SYSTEM == 'Windows':
@@ -242,7 +250,7 @@ class QueenbeeTask(luigi.Task):
 
         self._copy_input_artifacts(dst)
         logger.info(f'Started running {self.__class__.__name__}...')
-
+        qb_logger.info(f'Started running {self.__class__.__name__}...')
         p = subprocess.Popen(
             command, stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT, shell=True, env=os.environ
@@ -251,12 +259,14 @@ class QueenbeeTask(luigi.Task):
         for line in iter(p.stdout.readline, b''):
             msg = line.decode('utf-8').strip()
             logger.info(msg)
+            qb_logger.info(msg)
 
         p.communicate()
 
         if p.returncode != 0:
             err_msg = f'\n\nFailed task: {self.__class__.__name__}.\n' \
                 'Run the command with --debug key to debug the workflow.\n\n'
+            qb_logger.error(err_msg)
             logger.error(err_msg)
             raise ValueError(err_msg)
 
@@ -274,7 +284,10 @@ class QueenbeeTask(luigi.Task):
             # folder is in use or running in debug mode
             # this is a temp folder so not deleting is not a major issue
             pass
-        logger.info(f'Finished running {self.__class__.__name__}...')
+        duration = datetime.now() - st_time
+        duration -= timedelta(microseconds=duration.microseconds)  # remove microseconds
+        logger.info(f'...finished running {self.__class__.__name__} in {duration}')
+        qb_logger.info(f'...finished running {self.__class__.__name__} in {duration}')
 
     @staticmethod
     def load_input_param(input_param):
@@ -339,7 +352,7 @@ LOGS_CONFIG = """
 keys: default
 
 [loggers]
-keys: root, luigi-interface
+keys: root, luigi-interface, queenbee-interface
 
 [handlers]
 keys: console, logfile
@@ -352,21 +365,29 @@ datefmt:%Y-%m-%d %H:%M:%S
 class: StreamHandler
 args: [sys.stdout,]
 formatter: default
+level: INFO
 
 [handler_logfile]
 class: FileHandler
 args: ['WORKFLOW.LOG',]
 formatter: default
+level: DEBUG
 
 [logger_root]
-level: WARNING
-handlers: console, logfile
+handlers: logfile
 qualname: root
 propagate=0
 
 [logger_luigi-interface]
-level: DEBUG
-handlers: console, logfile
+handlers: logfile
 qualname: luigi-interface
 propagate=0
+level: DEBUG
+
+[logger_queenbee-interface]
+handlers: console
+qualname: queenbee-interface
+propagate=0
+level: INFO
+
 """
